@@ -13,12 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
+import functools
+
 from oslo_config import cfg
 from oslo_log import log as logging
 from stevedore import driver
 
+from cloudkitty import dataframe
 from cloudkitty.storage import v2 as storage_v2
-
+from cloudkitty.utils import tz as tzutils
 
 LOG = logging.getLogger(__name__)
 
@@ -63,13 +66,30 @@ class V1StorageAdapter(storage_v2.BaseStorage):
     def __init__(self, storage_args, storage_namespace, backend=None):
         self.storage = _get_storage_instance(
             storage_args, storage_namespace, backend=backend)
+        self._localize_dataframes = functools.partial(
+            self.__update_frames_timestamps, tzutils.utc_to_local)
+        self._make_dataframes_naive = functools.partial(
+            self.__update_frames_timestamps, tzutils.local_to_utc, naive=True)
 
     def init(self):
         return self.storage.init()
 
-    def push(self, dataframes, scope_id):
+    @staticmethod
+    def __update_frames_timestamps(func, frames, **kwargs):
+        for frame in frames:
+            start = frame.start
+            end = frame.end
+            if start:
+                frame.start = func(start, **kwargs)
+            if end:
+                frame.end = func(end, **kwargs)
+
+    def push(self, dataframes, scope_id=None):
         if dataframes:
-            self.storage.append(dataframes, scope_id)
+            self._make_dataframes_naive(dataframes)
+            self.storage.append(
+                [d.as_dict(mutable=True, legacy=True) for d in dataframes],
+                scope_id)
             self.storage.commit(scope_id)
 
     @staticmethod
@@ -85,36 +105,53 @@ class V1StorageAdapter(storage_v2.BaseStorage):
         tenant_id = filters.get('project_id') if filters else None
         metric_types = self._check_metric_types(metric_types)
         frames = self.storage.get_time_frame(
-            begin, end,
+            tzutils.local_to_utc(begin, naive=True) if begin else None,
+            tzutils.local_to_utc(end, naive=True) if end else None,
             res_type=metric_types,
             tenant_id=tenant_id)
-
+        frames = [dataframe.DataFrame.from_dict(frame, legacy=True)
+                  for frame in frames]
+        self._localize_dataframes(frames)
         return {
             'total': len(frames),
             'dataframes': frames,
         }
 
-    def total(self, groupby=None,
-              begin=None, end=None,
-              metric_types=None,
-              filters=None,
-              offset=0, limit=100, paginate=True):
-        tenant_id = filters.get('project_id') if filters else None
+    @staticmethod
+    def _localize_total(iterable):
+        for elem in iterable:
+            begin = elem['begin']
+            end = elem['end']
+            if begin:
+                elem['begin'] = tzutils.utc_to_local(begin)
+            if end:
+                elem['end'] = tzutils.utc_to_local(end)
 
-        storage_gby = []
-        if groupby:
-            for elem in set(groupby):
-                if elem == 'type':
-                    storage_gby.append('res_type')
-                elif elem == 'project_id':
-                    storage_gby.append('tenant_id')
-        storage_gby = ','.join(storage_gby) if storage_gby else None
-        metric_types = self._check_metric_types(metric_types)
-        total = self.storage.get_total(
-            begin, end,
-            tenant_id=tenant_id,
-            service=metric_types,
-            groupby=storage_gby)
+    def total(self, **arguments):
+        filters = arguments.pop('filters', None)
+        if filters:
+            tenant_id = filters.get('project_id')
+
+            arguments['tenant_id'] = tenant_id
+        else:
+            tenant_id = None
+
+        groupby = arguments.get('groupby')
+        storage_gby = self.get_storage_groupby(groupby)
+
+        metric_types = arguments.pop('metric_types', None)
+        if metric_types:
+            metric_types = self._check_metric_types(metric_types)
+            arguments['service'] = metric_types
+
+        arguments['begin'] = tzutils.local_to_utc(
+            arguments['begin'], naive=True)
+        arguments['end'] = tzutils.local_to_utc(
+            arguments['end'], naive=True)
+
+        arguments['groupby'] = storage_gby
+
+        total = self.storage.get_total(**arguments)
 
         for t in total:
             if t.get('tenant_id') is None:
@@ -125,14 +162,25 @@ class V1StorageAdapter(storage_v2.BaseStorage):
                 t['type'] = t.get('res_type')
             else:
                 t['type'] = None
+        self._localize_total(total)
         return {
             'total': len(total),
             'results': total,
         }
 
+    @staticmethod
+    def get_storage_groupby(groupby):
+        storage_gby = []
+        if groupby:
+            for elem in set(groupby):
+                if elem == 'type':
+                    storage_gby.append('res_type')
+                elif elem == 'project_id':
+                    storage_gby.append('tenant_id')
+        return ','.join(storage_gby) if storage_gby else None
+
     def get_tenants(self, begin, end):
-        tenants = self.storage.get_tenants(begin, end)
-        return tenants
+        return self.storage.get_tenants(begin, end)
 
     def get_state(self, tenant_id=None):
         return self.storage.get_state(tenant_id)
