@@ -69,9 +69,13 @@ class MetricConfigValidationTest(tests.TestCase):
         expected_output = copy.deepcopy(self.base_output)
         expected_output['metric_one']['groupby'] += ['project_id', 'id']
         expected_output['metric_one']['extra_args'] = {
-            'aggregation_method': 'max', 're_aggregation_method': 'max',
-            'force_granularity': 3600, 'resource_type': 'res',
-            'resource_key': 'id', 'use_all_resource_revisions': True}
+            'aggregation_method': 'max',
+            're_aggregation_method': 'max',
+            'force_granularity': 3600,
+            'resource_type': 'res',
+            'resource_key': 'id',
+            'use_all_resource_revisions': True,
+            'custom_query': ''}
 
         self.assertEqual(
             collector.gnocchi.GnocchiCollector.check_configuration(data),
@@ -131,6 +135,8 @@ class MetricConfigValidationTest(tests.TestCase):
         expected_output['metric_one']['groupby'].append('project_id')
         expected_output['metric_one']['extra_args'] = {
             'aggregation_method': 'max',
+            'query_prefix': '',
+            'query_suffix': '',
         }
         self.assertEqual(
             collector.prometheus.PrometheusCollector.check_configuration(data),
@@ -143,6 +149,8 @@ class MetricConfigValidationTest(tests.TestCase):
         expected_output['metric_one']['groupby'].append('project_id')
         expected_output['metric_one']['extra_args'] = {
             'aggregation_method': 'max',
+            'query_prefix': '',
+            'query_suffix': '',
         }
         self.assertEqual(
             collector.prometheus.PrometheusCollector.check_configuration(data),
@@ -154,6 +162,8 @@ class MetricConfigValidationTest(tests.TestCase):
         data['metrics']['metric_one']['extra_args'] = {
             'aggregation_method': 'max',
             'query_function': 'abs',
+            'query_prefix': 'custom_prefix',
+            'query_suffix': 'custom_suffix',
             'range_function': 'delta',
         }
         expected_output = copy.deepcopy(self.base_output)
@@ -161,6 +171,8 @@ class MetricConfigValidationTest(tests.TestCase):
         expected_output['metric_one']['extra_args'] = {
             'aggregation_method': 'max',
             'query_function': 'abs',
+            'query_prefix': 'custom_prefix',
+            'query_suffix': 'custom_suffix',
             'range_function': 'delta',
         }
 
